@@ -1,9 +1,9 @@
-from Orange.bio import obiGene
+import Orange.bio.gene
 
 #matching targets are NCBI gene IDs
-targets = obiGene.NCBIGeneInfo("Homo sapiens").keys()
+targets = Orange.bio.gene.NCBIGeneInfo("Homo sapiens").keys()
 
-gm = obiGene.GMNCBI("9606")
+gm = Orange.bio.gene.GMNCBI("9606")
 gm.set_targets(targets)
 
 for gene in [ "cct7", "pls1", "gdi1", "nfkb2", "dlg7" ]:
